@@ -2,8 +2,9 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from dev0s.classes.files import *
-from dev0s.classes import installation
+from dev0s.classes.defaults.files import *
+from dev0s.classes.manager import installation
+from dev0s.classes import console
 
 # the manager object class.
 class Manager(object):
@@ -33,7 +34,7 @@ class Manager(object):
 				if not installed.file_path.exists(): install = True
 				elif installed.load() != current.load(): install = True
 				if install: 
-					loader = Console.Loader(f"Installing library {installed.file_path.name()}")
+					loader = console.Loader(f"Installing library {installed.file_path.name()}")
 					os.system(f"sudo rm -fr {installed.file_path.path} && sudo cp -r {current.file_path.path} {installed.file_path.path} && sudo chmod +x {installed.file_path.path} && sudo chown {OWNER}:{GROUP} {installed.file_path.path}")
 					if not installed.file_path.exists(): loader.stop(success=False)
 					else: loader.stop()
