@@ -4,7 +4,6 @@
 # imports.
 from dev0s.classes.defaults.exceptions import Exceptions
 from dev0s.classes.defaults.files import *
-from dev0s.classes.utils.copycats import Docs
 
 # pip imports.
 from django.http import JsonResponse
@@ -16,10 +15,10 @@ class Response(object):
 	def __init__(self):	
 
 		# docs.
-		Docs.__init__(self,
-			initialized=True,
-			module="dev0s.response", 
-			notes=[], )
+		DOCS = {
+			"module":"dev0s.response", 
+			"initialized":True,
+			"description":[], }
 
 		# set log file.
 		#	assign new values with self.log_file.assign(...) to keep it shared across other objects.
@@ -342,10 +341,10 @@ class Parameters(object):
 	def __init__(self):
 		
 		# docs.
-		Docs.__init__(self,
-			initialized=True,
-			module="dev0s.response.parameters", 
-			notes=[], )
+		DOCS = {
+			"module":"dev0s.response.parameters", 
+			"initialized":True,
+			"description":[], }
 
 		#
 	# get request parameters.
